==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/HoleDimensionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HoleDimensionsChangedEventArgsDescription } from "./HoleDimensionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let HoleDimensionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class HoleDimensionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (HoleDimensionsChangedEventArgsDescriptionMetadata.a == null) {
                HoleDimensionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HoleDimensionsChangedEventArgsDescriptionMetadata.c(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(HoleDimensionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            HoleDimensionsChangedEventArgsDescriptionMetadata.b(a);
            a.aa("HoleDimensionsChangedEventArgs", () => new HoleDimensionsChangedEventArgsDescription());
            a.z("HoleDimensionsChangedEventArgs", HoleDimensionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    HoleDimensionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(HoleDimensionsChangedEventArgsDescriptionMetadata, 'HoleDimensionsChangedEventArgsDescriptionMetadata');
    HoleDimensionsChangedEventArgsDescriptionMetadata.a = null;
    return HoleDimensionsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/HoleDimensionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HoleDimensionsChangedEventArgsDescription } from "./HoleDimensionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let HoleDimensionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class HoleDimensionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (HoleDimensionsChangedEventArgsDescriptionMetadata.a == null) {
                HoleDimensionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HoleDimensionsChangedEventArgsDescriptionMetadata.c(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(HoleDimensionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(HoleDimensionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            HoleDimensionsChangedEventArgsDescriptionMetadata.b(a);
            a.ac("HoleDimensionsChangedEventArgs", () => new HoleDimensionsChangedEventArgsDescription());
            a.ab("HoleDimensionsChangedEventArgs", HoleDimensionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    HoleDimensionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(HoleDimensionsChangedEventArgsDescriptionMetadata, 'HoleDimensionsChangedEventArgsDescriptionMetadata');
    HoleDimensionsChangedEventArgsDescriptionMetadata.a = null;
    return HoleDimensionsChangedEventArgsDescriptionMetadata;
})();
